
# This is a fix for InnoDB in MySQL >= 4.1.x
# It "suspends judgement" for fkey relationships until are tables are set.
SET FOREIGN_KEY_CHECKS = 0;

#-----------------------------------------------------------------------------
#-- con_facultades
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `con_facultades`;


CREATE TABLE `con_facultades`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(255),
	`establecimiento_id` INTEGER,
	`activa` INTEGER default 1,
	`nombre_largo` VARCHAR(50),
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- con_carreras
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `con_carreras`;


CREATE TABLE `con_carreras`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`con_facultades_id` INTEGER,
	`NOMBRE` VARCHAR(255),
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- claustro
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `claustro`;


CREATE TABLE `claustro`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(45),
	`cantidad` INTEGER,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- consejero
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `consejero`;


CREATE TABLE `consejero`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50),
	`apellido` VARCHAR(50),
	`direccion` VARCHAR(100),
	`dni` VARCHAR(20),
	`telefono` VARCHAR(30),
	`email` VARCHAR(50),
	`lugar_nac` VARCHAR(50),
	`fecha_nac` DATE,
	`nacionalidad` VARCHAR(50),
	`con_estado_civil_id` INTEGER,
	`con_localidades_id` INTEGER,
	`con_provincias_id` INTEGER,
	`facultad_id` INTEGER,
	PRIMARY KEY (`id`),
	KEY `dni`(`dni`),
	INDEX `consejero_FI_1` (`con_estado_civil_id`),
	CONSTRAINT `consejero_FK_1`
		FOREIGN KEY (`con_estado_civil_id`)
		REFERENCES `con_estado_civil` (`id`),
	INDEX `consejero_FI_2` (`con_localidades_id`),
	CONSTRAINT `consejero_FK_2`
		FOREIGN KEY (`con_localidades_id`)
		REFERENCES `con_localidades` (`id`),
	INDEX `consejero_FI_3` (`con_provincias_id`),
	CONSTRAINT `consejero_FK_3`
		FOREIGN KEY (`con_provincias_id`)
		REFERENCES `con_provincias` (`id`),
	INDEX `consejero_FI_4` (`facultad_id`),
	CONSTRAINT `consejero_FK_4`
		FOREIGN KEY (`facultad_id`)
		REFERENCES `con_facultades` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- con_estado_civil
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `con_estado_civil`;


CREATE TABLE `con_estado_civil`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(15),
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- con_localidades
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `con_localidades`;


CREATE TABLE `con_localidades`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(255),
	`con_provincias_id` INTEGER,
	`cod_postal` VARCHAR(20),
	PRIMARY KEY (`id`),
	INDEX `con_localidades_FI_1` (`con_provincias_id`),
	CONSTRAINT `con_localidades_FK_1`
		FOREIGN KEY (`con_provincias_id`)
		REFERENCES `con_provincias` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- con_provincias
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `con_provincias`;


CREATE TABLE `con_provincias`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(255),
	`cod_prov` VARCHAR,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- con_sedes
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `con_sedes`;


CREATE TABLE `con_sedes`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(255),
	`con_localidades_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `con_sedes_FI_1` (`con_localidades_id`),
	CONSTRAINT `con_sedes_FK_1`
		FOREIGN KEY (`con_localidades_id`)
		REFERENCES `con_localidades` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- con_paises
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `con_paises`;


CREATE TABLE `con_paises`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50),
	`nombre_largo` VARCHAR(255),
	`orden` INTEGER,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- sf_guard_user_profile
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `sf_guard_user_profile`;


CREATE TABLE `sf_guard_user_profile`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`user_id` INTEGER  NOT NULL,
	`first_name` VARCHAR,
	`last_name` VARCHAR,
	`fecha_nac` DATE,
	`email` VARCHAR,
	`created_at` DATETIME,
	`foto` VARCHAR,
	PRIMARY KEY (`id`),
	INDEX `sf_guard_user_profile_FI_1` (`user_id`),
	CONSTRAINT `sf_guard_user_profile_FK_1`
		FOREIGN KEY (`user_id`)
		REFERENCES `sf_guard_user` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- reunion
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `reunion`;


CREATE TABLE `reunion`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`titulo` VARCHAR(45)  NOT NULL,
	`etiquetas` VARCHAR(45),
	`lugar` VARCHAR(45),
	`fecha` DATETIME,
	`orden_deldia` TEXT,
	`created_at` DATETIME,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- reunion_asistencia
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `reunion_asistencia`;


CREATE TABLE `reunion_asistencia`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`reunion_id` INTEGER,
	`consejero_id` INTEGER,
	`confirma_asistencia` INTEGER default 0 NOT NULL,
	`confirma_fecha` DATE,
	`asistio` INTEGER default 0 NOT NULL,
	`motivo` VARCHAR(100),
	PRIMARY KEY (`id`),
	INDEX `reunion_asistencia_FI_1` (`reunion_id`),
	CONSTRAINT `reunion_asistencia_FK_1`
		FOREIGN KEY (`reunion_id`)
		REFERENCES `reunion` (`id`),
	INDEX `reunion_asistencia_FI_2` (`consejero_id`),
	CONSTRAINT `reunion_asistencia_FK_2`
		FOREIGN KEY (`consejero_id`)
		REFERENCES `consejero` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- notificacion
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `notificacion`;


CREATE TABLE `notificacion`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`fecha` DATE,
	`referencia` VARCHAR(255),
	`enviada` INTEGER default 0 NOT NULL,
	`adjuntos` TEXT,
	`cuerpo` TEXT,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- notificacion_consejero
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `notificacion_consejero`;


CREATE TABLE `notificacion_consejero`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`notificacion_id` INTEGER,
	`consejero_id` INTEGER,
	`claustro_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `notificacion_consejero_FI_1` (`notificacion_id`),
	CONSTRAINT `notificacion_consejero_FK_1`
		FOREIGN KEY (`notificacion_id`)
		REFERENCES `notificacion` (`id`),
	INDEX `notificacion_consejero_FI_2` (`consejero_id`),
	CONSTRAINT `notificacion_consejero_FK_2`
		FOREIGN KEY (`consejero_id`)
		REFERENCES `consejero` (`id`),
	INDEX `notificacion_consejero_FI_3` (`claustro_id`),
	CONSTRAINT `notificacion_consejero_FK_3`
		FOREIGN KEY (`claustro_id`)
		REFERENCES `claustro` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- notificacion_comision
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `notificacion_comision`;


CREATE TABLE `notificacion_comision`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`notificacion_id` INTEGER,
	`comision_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `notificacion_comision_FI_1` (`notificacion_id`),
	CONSTRAINT `notificacion_comision_FK_1`
		FOREIGN KEY (`notificacion_id`)
		REFERENCES `notificacion` (`id`),
	INDEX `notificacion_comision_FI_2` (`comision_id`),
	CONSTRAINT `notificacion_comision_FK_2`
		FOREIGN KEY (`comision_id`)
		REFERENCES `comision` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- nota
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `nota`;


CREATE TABLE `nota`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(128)  NOT NULL,
	`referencia` TEXT,
	`encabezado` VARCHAR(128),
	`cuerpo` TEXT,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- comision
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `comision`;


CREATE TABLE `comision`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`consejero_id` INTEGER,
	`nombre` VARCHAR(128)  NOT NULL,
	`titular` VARCHAR(128)  NOT NULL,
	`direccion` VARCHAR(128),
	`referencia` TEXT,
	PRIMARY KEY (`id`),
	INDEX `comision_FI_1` (`consejero_id`),
	CONSTRAINT `comision_FK_1`
		FOREIGN KEY (`consejero_id`)
		REFERENCES `consejero` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- comision_consejero
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `comision_consejero`;


CREATE TABLE `comision_consejero`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`consejero_id` INTEGER  NOT NULL,
	`comision_id` INTEGER  NOT NULL,
	`created_at` DATETIME,
	PRIMARY KEY (`id`),
	INDEX `comision_consejero_FI_1` (`consejero_id`),
	CONSTRAINT `comision_consejero_FK_1`
		FOREIGN KEY (`consejero_id`)
		REFERENCES `consejero` (`id`),
	INDEX `comision_consejero_FI_2` (`comision_id`),
	CONSTRAINT `comision_consejero_FK_2`
		FOREIGN KEY (`comision_id`)
		REFERENCES `comision` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- claustro_consejero
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `claustro_consejero`;


CREATE TABLE `claustro_consejero`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`claustro_id` INTEGER,
	`consejero_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `claustro_consejero_FI_1` (`claustro_id`),
	CONSTRAINT `claustro_consejero_FK_1`
		FOREIGN KEY (`claustro_id`)
		REFERENCES `claustro` (`id`),
	INDEX `claustro_consejero_FI_2` (`consejero_id`),
	CONSTRAINT `claustro_consejero_FK_2`
		FOREIGN KEY (`consejero_id`)
		REFERENCES `consejero` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- alumno
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `alumno`;


CREATE TABLE `alumno`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50),
	`apellido` VARCHAR(50),
	`dni` INTEGER,
	`nacionalidad` VARCHAR(50),
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- expediente
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `expediente`;


CREATE TABLE `expediente`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`con_facultades_id` INTEGER,
	`con_carreras_id` INTEGER,
	`alumno_id` INTEGER,
	`nro_exp_fac` VARCHAR(45),
	`fecha_inicio` DATE,
	`fecha_pase_ministerio` DATE,
	`fecha_recibido_ministerio` DATE,
	`fecha_pase_sec_adm` DATE,
	`fecha_recibido_sec_adm` DATE,
	`fecha_retiro_fac` DATE,
	`created_at` DATETIME,
	`observaciones` TEXT,
	`res_rectoral` INTEGER,
	`res_rectoral_fecha` DATE,
	`fecha_egreso_alumno` DATE,
	`reg_universitario` VARCHAR(45),
	PRIMARY KEY (`id`),
	INDEX `expediente_FI_1` (`con_facultades_id`),
	CONSTRAINT `expediente_FK_1`
		FOREIGN KEY (`con_facultades_id`)
		REFERENCES `con_facultades` (`id`),
	INDEX `expediente_FI_2` (`con_carreras_id`),
	CONSTRAINT `expediente_FK_2`
		FOREIGN KEY (`con_carreras_id`)
		REFERENCES `con_carreras` (`id`),
	INDEX `expediente_FI_3` (`alumno_id`),
	CONSTRAINT `expediente_FK_3`
		FOREIGN KEY (`alumno_id`)
		REFERENCES `alumno` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- expediente_pasefacultad
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `expediente_pasefacultad`;


CREATE TABLE `expediente_pasefacultad`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`expediente_id` INTEGER,
	`fecha_pase` DATE,
	`fecha_retorno` DATE,
	`observaciones` TEXT,
	PRIMARY KEY (`id`),
	INDEX `expediente_pasefacultad_FI_1` (`expediente_id`),
	CONSTRAINT `expediente_pasefacultad_FK_1`
		FOREIGN KEY (`expediente_id`)
		REFERENCES `expediente` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- sexo
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `sexo`;


CREATE TABLE `sexo`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50),
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- personal
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `personal`;


CREATE TABLE `personal`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`dni` INTEGER  NOT NULL,
	`cuil` VARCHAR(20),
	`reparticion` VARCHAR(50),
	`legajo` VARCHAR(20),
	`sexo_id` INTEGER,
	`apellido` VARCHAR(50)  NOT NULL,
	`nombre` VARCHAR(50)  NOT NULL,
	`fecha_nac` DATE,
	`direccion` VARCHAR(50),
	`dir_barrio` VARCHAR(50),
	`dir_calle` VARCHAR(50),
	`dir_nro` VARCHAR(10),
	`dir_manzana` VARCHAR(50),
	`dir_lote` VARCHAR(50),
	`dir_monoblock` VARCHAR(50),
	`dir_piso` VARCHAR(50),
	`dir_dpto` VARCHAR(50),
	`dir_puntodereferencia` VARCHAR(50),
	`dir_otrosdatos` VARCHAR(50),
	`telefono` VARCHAR(50),
	`con_provincias_id` INTEGER,
	`con_localidades_id` INTEGER,
	`email` VARCHAR(50),
	`observaciones` TEXT,
	`hs_cumple` TIME default '06:00:00' NOT NULL,
	`hs_entrada` TIME default '07:00:00' NOT NULL,
	`hs_salida` TIME default '13:00:00' NOT NULL,
	`activo` INTEGER default 1,
	PRIMARY KEY (`id`),
	UNIQUE KEY `doc` (`dni`),
	KEY `Apellido`(`apellido`),
	INDEX `personal_FI_1` (`sexo_id`),
	CONSTRAINT `personal_FK_1`
		FOREIGN KEY (`sexo_id`)
		REFERENCES `sexo` (`id`),
	INDEX `personal_FI_2` (`con_provincias_id`),
	CONSTRAINT `personal_FK_2`
		FOREIGN KEY (`con_provincias_id`)
		REFERENCES `con_provincias` (`id`),
	INDEX `personal_FI_3` (`con_localidades_id`),
	CONSTRAINT `personal_FK_3`
		FOREIGN KEY (`con_localidades_id`)
		REFERENCES `con_localidades` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- personal_turno
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `personal_turno`;


CREATE TABLE `personal_turno`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`turno_id` INTEGER,
	`personal_id` INTEGER,
	`hora_entrada` TIME default '07:00' NOT NULL,
	`hora_salida` TIME default '13:00' NOT NULL,
	`activo` INTEGER default 1,
	`observaciones` TEXT,
	PRIMARY KEY (`id`),
	INDEX `personal_turno_FI_1` (`turno_id`),
	CONSTRAINT `personal_turno_FK_1`
		FOREIGN KEY (`turno_id`)
		REFERENCES `turno` (`id`),
	INDEX `personal_turno_FI_2` (`personal_id`),
	CONSTRAINT `personal_turno_FK_2`
		FOREIGN KEY (`personal_id`)
		REFERENCES `personal` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- turno
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `turno`;


CREATE TABLE `turno`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(20)  NOT NULL,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- inasistencia_tipo
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `inasistencia_tipo`;


CREATE TABLE `inasistencia_tipo`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50)  NOT NULL,
	`observaciones` TEXT,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- licencia_tipo
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `licencia_tipo`;


CREATE TABLE `licencia_tipo`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50)  NOT NULL,
	`anexo` VARCHAR(10),
	`dias_maximo` INTEGER,
	`dias_minimo` INTEGER default 1,
	`dias_tipo_id` INTEGER,
	`observaciones` TEXT,
	PRIMARY KEY (`id`),
	INDEX `licencia_tipo_FI_1` (`dias_tipo_id`),
	CONSTRAINT `licencia_tipo_FK_1`
		FOREIGN KEY (`dias_tipo_id`)
		REFERENCES `dias_tipo` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- personal_inasistencias
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `personal_inasistencias`;


CREATE TABLE `personal_inasistencias`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`id_establecimiento` INTEGER default 1,
	`personal_id` INTEGER default null NOT NULL,
	`inasistencia_tipo_id` INTEGER,
	`hora_entrada` TIME,
	`hora_salida` TIME,
	`fecha` DATE  NOT NULL,
	`observaciones` TEXT(255),
	`turno_id` INTEGER,
	`cargo_id` INTEGER default 0,
	`cantidad_dias` INTEGER default 0 NOT NULL,
	PRIMARY KEY (`id`),
	UNIQUE KEY `Personal_inasistencias01` (`fecha`, `personal_id`),
	KEY `fk_personal`(`personal_id`),
	CONSTRAINT `personal_inasistencias_FK_1`
		FOREIGN KEY (`personal_id`)
		REFERENCES `personal` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	INDEX `personal_inasistencias_FI_2` (`inasistencia_tipo_id`),
	CONSTRAINT `personal_inasistencias_FK_2`
		FOREIGN KEY (`inasistencia_tipo_id`)
		REFERENCES `inasistencia_tipo` (`id`),
	INDEX `personal_inasistencias_FI_3` (`turno_id`),
	CONSTRAINT `personal_inasistencias_FK_3`
		FOREIGN KEY (`turno_id`)
		REFERENCES `turno` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- personal_licencias
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `personal_licencias`;


CREATE TABLE `personal_licencias`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`id_establecimiento` INTEGER default 1,
	`personal_id` INTEGER,
	`licencia_tipo_id` INTEGER,
	`fecha_inicio` DATE,
	`fecha_fin` DATE,
	`observaciones` TEXT(255),
	`familiar_id` INTEGER,
	`cargo_id` INTEGER default 0,
	`cantidad_dias` INTEGER default 0 NOT NULL,
	PRIMARY KEY (`id`),
	INDEX `personal_licencias_FI_1` (`personal_id`),
	CONSTRAINT `personal_licencias_FK_1`
		FOREIGN KEY (`personal_id`)
		REFERENCES `personal` (`id`),
	INDEX `personal_licencias_FI_2` (`licencia_tipo_id`),
	CONSTRAINT `personal_licencias_FK_2`
		FOREIGN KEY (`licencia_tipo_id`)
		REFERENCES `licencia_tipo` (`id`),
	INDEX `personal_licencias_FI_3` (`familiar_id`),
	CONSTRAINT `personal_licencias_FK_3`
		FOREIGN KEY (`familiar_id`)
		REFERENCES `familiar` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- familiar
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `familiar`;


CREATE TABLE `familiar`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`DNI` INTEGER,
	`personal_id` INTEGER,
	`apellido` VARCHAR(50),
	`nombre` VARCHAR(50),
	`sexo_id` INTEGER,
	`fecha_nac` DATE,
	`parentesco_id` INTEGER,
	`observaciones` TEXT,
	PRIMARY KEY (`id`),
	INDEX `familiar_FI_1` (`personal_id`),
	CONSTRAINT `familiar_FK_1`
		FOREIGN KEY (`personal_id`)
		REFERENCES `personal` (`id`),
	INDEX `familiar_FI_2` (`sexo_id`),
	CONSTRAINT `familiar_FK_2`
		FOREIGN KEY (`sexo_id`)
		REFERENCES `sexo` (`id`),
	INDEX `familiar_FI_3` (`parentesco_id`),
	CONSTRAINT `familiar_FK_3`
		FOREIGN KEY (`parentesco_id`)
		REFERENCES `parentesco` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- parentesco
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `parentesco`;


CREATE TABLE `parentesco`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50),
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- anexo
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `anexo`;


CREATE TABLE `anexo`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50),
	`cuerpo` TEXT,
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- dias_tipo
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `dias_tipo`;


CREATE TABLE `dias_tipo`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(50),
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- personal_familiar
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `personal_familiar`;


CREATE TABLE `personal_familiar`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`personal_id` INTEGER,
	`familiar_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `personal_familiar_FI_1` (`personal_id`),
	CONSTRAINT `personal_familiar_FK_1`
		FOREIGN KEY (`personal_id`)
		REFERENCES `personal` (`id`),
	INDEX `personal_familiar_FI_2` (`familiar_id`),
	CONSTRAINT `personal_familiar_FK_2`
		FOREIGN KEY (`familiar_id`)
		REFERENCES `familiar` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- art_alumno
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `art_alumno`;


CREATE TABLE `art_alumno`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(100),
	`apellido` VARCHAR(100),
	`fecha_nac` DATE,
	`domicilio` VARCHAR(50),
	`dni` VARCHAR(20),
	`telefono` VARCHAR(30),
	`email` VARCHAR(50),
	`con_localidades_id` INTEGER,
	`escuela_turno_id` INTEGER  NOT NULL,
	`escuela_nombre` VARCHAR(255),
	`escuela_domicilio` VARCHAR(255),
	`escuela_con_provincias_id` INTEGER default null NOT NULL,
	`escuela_con_localidades_id` INTEGER default null NOT NULL,
	`escuela_egreso` INTEGER(50),
	`escuela_modalidad` VARCHAR(100),
	`escuela_pendientes` VARCHAR(255),
	`otros_orientacion` INTEGER default 0,
	`otros_informatica` INTEGER default 0,
	`otros_trabaja` VARCHAR(255),
	`otros_informatica_cuales` VARCHAR(255),
	`carrera_interesado` VARCHAR(255),
	`sede_cursado` VARCHAR(100),
	`con_provincias_id` INTEGER,
	`anio` INTEGER(11),
	PRIMARY KEY (`id`),
	INDEX `art_alumno_FI_1` (`con_localidades_id`),
	CONSTRAINT `art_alumno_FK_1`
		FOREIGN KEY (`con_localidades_id`)
		REFERENCES `con_localidades` (`id`),
	INDEX `art_alumno_FI_2` (`escuela_turno_id`),
	CONSTRAINT `art_alumno_FK_2`
		FOREIGN KEY (`escuela_turno_id`)
		REFERENCES `turno` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	INDEX `art_alumno_FI_3` (`escuela_con_provincias_id`),
	CONSTRAINT `art_alumno_FK_3`
		FOREIGN KEY (`escuela_con_provincias_id`)
		REFERENCES `con_provincias` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	INDEX `art_alumno_FI_4` (`escuela_con_localidades_id`),
	CONSTRAINT `art_alumno_FK_4`
		FOREIGN KEY (`escuela_con_localidades_id`)
		REFERENCES `con_localidades` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	INDEX `art_alumno_FI_5` (`con_provincias_id`),
	CONSTRAINT `art_alumno_FK_5`
		FOREIGN KEY (`con_provincias_id`)
		REFERENCES `con_provincias` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- art_modulo
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `art_modulo`;


CREATE TABLE `art_modulo`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nombre` VARCHAR(120)  NOT NULL,
	`observaciones` VARCHAR(255),
	PRIMARY KEY (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- art_alumno_modulo
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `art_alumno_modulo`;


CREATE TABLE `art_alumno_modulo`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`art_alumno_id` INTEGER,
	`art_modulo_id` INTEGER,
	`art_comision_id` INTEGER,
	`horario` VARCHAR(255),
	`aprobado` INTEGER default 0,
	`fecha_aprobado` DATE,
	`nota` INTEGER,
	`cubre_asistencia` INTEGER default 0,
	`anio` INTEGER,
	`recupero` INTEGER default 0,
	PRIMARY KEY (`id`),
	INDEX `art_alumno_modulo_FI_1` (`art_alumno_id`),
	CONSTRAINT `art_alumno_modulo_FK_1`
		FOREIGN KEY (`art_alumno_id`)
		REFERENCES `art_alumno` (`id`),
	INDEX `art_alumno_modulo_FI_2` (`art_modulo_id`),
	CONSTRAINT `art_alumno_modulo_FK_2`
		FOREIGN KEY (`art_modulo_id`)
		REFERENCES `art_modulo` (`id`),
	INDEX `art_alumno_modulo_FI_3` (`art_comision_id`),
	CONSTRAINT `art_alumno_modulo_FK_3`
		FOREIGN KEY (`art_comision_id`)
		REFERENCES `art_comision` (`id`)
)Type=MyISAM;

#-----------------------------------------------------------------------------
#-- art_comision
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `art_comision`;


CREATE TABLE `art_comision`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`art_modulo_id` INTEGER,
	`carga_horaria` INTEGER,
	`nombre` VARCHAR(255),
	`lugar` VARCHAR(255),
	`horario` VARCHAR(255),
	`profesor_apellido` VARCHAR(255),
	`profesor_nombre` VARCHAR(255),
	PRIMARY KEY (`id`),
	INDEX `art_comision_FI_1` (`art_modulo_id`),
	CONSTRAINT `art_comision_FK_1`
		FOREIGN KEY (`art_modulo_id`)
		REFERENCES `art_modulo` (`id`)
)Type=MyISAM;

# This restores the fkey checks, after having unset them earlier
SET FOREIGN_KEY_CHECKS = 1;
