<?php
/**
 * For the full copyright and license information, please view the LICENSE file that was distributed with this source code.
 */
/**
 * This class holds the Multi Series {@link http://www.fusioncharts.com/free/docs/?gMenuItemId=19 FusionCharts} XML specific functions
 *
 * @author Bart Vanderstukken <bart@digitalbase.eu>
 * @copyright (c) 2007-2008 Digital Base BVBA <{@link mailto:info@digitalbase.eu info@digitalbase.eu}> - See LICENSE
 * @package dbFusionChart
 *
 */
class dbFC_Multi_Auto extends dbFC_Multi
{
  /**
   * generates array[serie][category] => value
   *
   * @param string $class
   * @param string $series_method
   * @param string $cat_method
   * @param string $value_method
   * @param Criteria $crit
   * @param string $peermethod
   * @return array
   */
  protected static function propelGenerate($class, $series_method, $cat_method, $value_method, $crit=null, $peermethod="doSelect")
  {
    if($crit) $c = clone $crit;
    else $c = new Criteria();

    if(!is_array($series_method)) $series_method = array($series_method);
    if(!is_array($cat_method)) $cat_method = array($cat_method);
    if(!is_array($value_method)) $value_method = array($value_method);

    $objects = call_user_func(array($class . "Peer", $peermethod), $c);

    foreach ($objects as $object)
    {
      $serie = self::call_recursive($object, $series_method);
      $category = self::call_recursive($object, $cat_method);
      $value = self::call_recursive($object, $value_method, false);

      @$data[$serie][$category] += $value/3600;
    }

    if(isset($data)) return $data;
  }

  /**
   * Adds datasets (& categories) with $data
   *
   * @param array $data $data[serie][category] => value expected
   */
  public function generateSets($data)
  {
    foreach ($data as $seriesName => $serie_array)
    { 
      $this->qAddDataSetWithValues($serie_array, $seriesName, $this->randomColor());
    }
  }

  /**
   * @param Base_Object $object
   * @param array $methods methods to call
   * @param boolean $null_possible if false, error will be thrown if chain has null value (non-object); if true => null found => "-" returned
   * @return string result of last call
   */
  private static function call_recursive($object, $methods, $null_possible=true)
  {
    $null = false;
    foreach ($methods as $method)
    {
      if($object == null && $null_possible)
      {
        $object = "-";
        $null = true;
      }
      elseif(!$null) $object = $object->$method();
    }

    return $object;
  }
}