<?php
/**
 * For the full copyright and license information, please view the LICENSE file that was distributed with this source code.
 */
/**
 * This class holds the Single Series {@link http://www.fusioncharts.com/free/docs/?gMenuItemId=19 FusionCharts} XML specific functions
 *
 * @author Bart Vanderstukken <bart@digitalbase.eu>
 * @copyright (c) 2007-2008 Digital Base BVBA <{@link mailto:info@digitalbase.eu info@digitalbase.eu}> - See LICENSE
 * @package dbFusionChart
 */
class dbFC_Single extends dbFusionChartXML
{
  /**
   * Adds a set-node
   *
   * @param string $label appears on the x-axis of chart, used as identifier
   * @param string $value plotted on the chart
   * @param array $atts other attributes for set node (name => value)
   * @param string $before_label label for set before which the data should be inserted; if not provided, set will be appended
   * @see qAddData
   * @return DOMElement
   * @todo integrate FC_Colors for Free version
   */
  public function addData($label, $value, $atts=array(), $before_label="")
  {
    $atts[LABEL] = $label;
    $atts["value"] = $value;

    if($before_label) $ref_node = $this->getSet($before_label);

    return $this->insertRootChild("set", $atts, $ref_node);
  }

  /**
   * Convenience method
   *
   * All arguments (most optional) correspond with the attributes as described in the {@link http://www.fusioncharts.com/free/docs/?gMenuItemId=19 FusionCharts Documentation} to date.<br />
   * Attributes that aren't included in the argument list, because we didn't regard them as current or because of changes/updates in the underlying FusionCharts software, can be passed in an array (att_name => value) via $atts.
   *
   * Default values are ignored; if the default value seems to be wrong, change it in the source code and please {@link mailto:info@digitalbase.eu inform us!}
   *
   * @param string $label appears on the x-axis of chart, used as identifier
   * @param string $value plotted on the chart
   * @param string $color hex color code without #
   *  - {@link http://www.fusioncharts.com/ FusionCharts V3}: if you want to define your own colors for the data items on chart, use this attribute to specify color for the data item
   *  - {@link http://www.fusioncharts.com/free FusionCharts FREE}: you'll <b>have</b> to create your own method to cycle colors (see {@link http://www.digitalbase.eu/dbFusionChart/doc/FC_colors.html FC_Colors})
   * @param URL $link define links for individual data items
   *  - {@link http://www.fusioncharts.com/ FusionCharts V3}: please see "{@link http://www.fusioncharts.com/Docs/Index.html Advanced Charting > Drill Down Charts}" for more information
   *  - {@link http://www.fusioncharts.com/free FusionCharts FREE}: to open a link in a new window, just put n- in front of the link
   * @param string $toolText by default, FusionCharts shows the data item name and value as tool tip text, but if you want to display more information, you can use this attribute to specify the same
   * @param boolean $showLabel show/hide labels of individual data items
   * @param int $alpha determines transparency of a data item, 0 means complete transparency (the data item wont be shown on the graph) and 100 means opaque
   * @param boolean $showValue show/hide values of individual data items <br />
   *   ONLY AVAILABLE IN {@link http://www.fusioncharts.com/ NON-FREE VERSION} OF FUSIONCHARTS
   * @param boolean $dashed border of this data item should appear as dashed? <br />
   *   ONLY AVAILABLE IN {@link http://www.fusioncharts.com/ NON-FREE VERSION} OF FUSIONCHARTS
   * @param array $atts extra attributes (name => value)
   * @param string $before_label label for set before which the data should be inserted; if not provided, set will be appended
   * @return DOMElement
   * @todo integrate FC_Colors for Free version
   */
  public function qAddData($label, $value, $color="", $link="", $toolText="", $showLabel=true, $alpha=null, $showValue=true, $dashed=false, $atts=array(), $before_label="")
  {
    if($color) $atts["color"] = $color;
    
    if($link) $atts["link"] = urlencode($link);
    if($toolText) $atts[TOOLTIP] = $toolText;
    if(!$showLabel) $atts[SHOWLABEL] = "0";
    if(isset($alpha)) $atts["alpha"] = "$alpha";
    if(VERSION == "V3")
    {
      if(!$showValue) $atts["showValue"] = "0";
      if($dashed) $atts["dashed"] = "1";
    }

    return $this->addData($label, $value, $atts, $before_label);
  }

  /**
   * @param string $before_label label of set before which the vertical data seperator line should be inserted
   * @param array $atts name => value
   */
  protected function addVline($before_label, $atts=array())
  {
    if(VERSION == "V3")
    {
      $this->insertRootChild("vLine", $atts, $this->getSet($before_label));
    }
    else throw new Exception("Only available in non-free version. If you have purchased FusionCharts V3, change the VERSION constant in config.php");
  }

  /**
   * @return DOMNodeList
   */
  public function getSets()
  {
    return $this->getChartNode()->getElementsByTagName("set");
  }

  /**
   * @param string $label
   * @return DOMElement set node, identified by $label
   */
  public function getSet($label)
  {
    $sets = $this->getSets();
    /* @var $setnode DOMElement */
    foreach ($sets as $setnode)
    {
      if($setnode->getAttribute("label") == $label) return $setnode;
    }
  }
}