<?php
/**
 * For the full copyright and license information, please view the LICENSE file that was distributed with this source code.
 */

/**
 *
 */
include_once("config.php");

/**
 * This class is used to create the required JavaScript
 *
 * @author Bart Vanderstukken <bart@digitalbase.eu>
 * @copyright (c) 2007-2008 Digital Base BVBA <{@link mailto:info@digitalbase.eu info@digitalbase.eu}> - See LICENSE
 * @package dbFusionChart
 */
class dbFusionChart
{
  const Column2D = "Column2D";
  const Column3D = "Column3D";
  const Pie3D = "Pie3D";
  const Pie2D = "Pie2D";
  const Line = "Line";
  const Bar2D = "Bar2D";
  const Area2D = "Area2D";
  const Doughnut2D = "Doughnut2D";
  const MSColumn2D = "MSColumn2D";
  const MSColumn3D = "MSColumn3D";
  const MSLine = "MSLine";
  const MSArea2D = "MSArea2D";
  const MSBar2D = "MSBar2D";
//  const MSBar3D = "MSBar3D";
  const StackedColumn2D = "StackedColumn2D";
  const StackedColumn3D = "StackedColumn3D";
  const StackedArea2D = "StackedArea2D";
  const StackedBar2D = "StackedBar2D";
  const SSGrid = "SSGrid";

  /** @var string */
  private $chartType;
  /** @var URL */
  private $dataURL;
  /** @var int */
  private $width;
  /** @var int */
  private $height;
  /** @var string */
  private $JSvar;
  /** @var string */
  private $divID;
  /** @var string */
  private $chartID;
  /** @var array */
  /*
  private static $types = array(
    self::Column2D => "FCF_Column2D.swf",
    self::Column3D => "FCF_Column3D.swf",
    self::Pie3D => "FCF_Pie3D.swf",
    self::Pie2D => "FCF_Pie2D.swf",
    self::Line => "FCF_Line.swf",
    self::Bar2D => "FCF_Bar2D.swf",
    self::Area2D => "FCF_Area2D.swf",
    self::Doughnut2D => "FCF_Doughnut2D.swf",
    self::MSColumn2D => "FCF_MSColumn2D.swf",
    self::MSColumn3D => "FCF_MSColumn3D.swf",
    self::MSLine => "FCF_MSLine.swf",
    self::MSArea2D => "FCF_MSArea2D.swf",
    self::MSBar2D => "FCF_MSBar2D.swf",
//  	self::MSBar3D => "MSBar3D.swf",
    self::StackedColumn2D => "FCF_StackedColumn2D.swf",
    self::StackedColumn3D => "FCF_StackedColumn3D.swf",
    self::StackedArea2D => "FCF_StackedArea2D.swf",
    self::StackedBar2D => "FCF_StackedBar2D.swf",
  */
  
  private static $types = array(
  	self::Column2D => "Column2D.swf",
  	self::Column3D => "Column3D.swf",
  	self::Pie3D => "Pie3D.swf",
  	self::Pie2D => "Pie2D.swf",
  	self::Line => "Line.swf",
  	self::Bar2D => "Bar2D.swf",
  	self::Area2D => "Area2D.swf",
  	self::Doughnut2D => "Doughnut2D.swf",
  	self::MSColumn2D => "MSColumn2D.swf",
  	self::MSColumn3D => "MSColumn3D.swf",
  	self::MSLine => "MSLine.swf",
  	self::MSArea2D => "MSArea2D.swf",
  	self::MSBar2D => "MSBar2D.swf",
//  	self::MSBar3D => "MSBar3D.swf",
  	self::StackedColumn2D => "StackedColumn2D.swf",
  	self::StackedColumn3D => "StackedColumn3D.swf",
  	self::StackedArea2D => "StackedArea2D.swf",
  	self::StackedBar2D => "StackedBar2D.swf",
    self::SSGrid => "SSGrid.swf",
  );

  /**
   * @param string $chartType valid chart type (use class constants), determines used swf file
   * @param URL $dataURL path to xml
   * @param string $width chart's width in pixels
   * @param string $height chart's height in pixels
   * @param string $JSvar if not provided, "chart_" + random(0,999)
   * @param string $divID if not provided, id will be "chart_div_" + random(0,999)
   * @param string $chartID if not provided, id will be "ch_" + random(0,999)
   */
  public function __construct($chartType, $dataURL, $width, $height, $JSvar="", $divID="", $chartID="")
  {
    $this->chartType = $chartType;
    $this->dataURL = $dataURL;
    $this->width = $width;
    $this->height = $height;
    if($JSvar) $this->JSvar = $JSvar;
    else $this->JSvar = "chart_" . rand(0,999);
    if($divID) $this->divID = $divID;
    else $this->divID = "chart_div_" . rand(0,999);
    if($chartID) $this->chartID = $chartID;
    else $this->chartID = "ch_" . rand(0,999);
  }

  /**
   * 'Magic' function
   *
   * @return string div (to hold chart) and JavaScript (to render content of div)
   */
  public function __toString()
  {
    return "
<div id=\"$this->divID\">
   This text is replaced by the chart.
</div>

<script type=\"text/javascript\">
   var $this->JSvar = new FusionCharts(\"".SWFPATH.self::$types[$this->chartType]."\", \"$this->chartID\", \"$this->width\", \"$this->height\", \"0\", \"0\");
   //To pass parameters, URLEncode the dataURL. Use escape() in JavaScript
   $this->JSvar.setDataURL(escape(\"$this->dataURL\"));
   $this->JSvar.render(\"$this->divID\")
</script>";
  }
}